@@ -1,14 +1,14 @@
 package App::PMUtils;
 
-our $DATE = '2016-07-17'; # DATE
-our $VERSION = '0.59'; # VERSION
+our $DATE = '2016-07-20'; # DATE
+our $VERSION = '0.60'; # VERSION
 
 use 5.010001;
 
 our %SPEC;
 
 our $arg_module_multiple = {
-    schema => ['array*' => of=>'str*', min_len=>1],
+    schema => ['array*' => of=>'perl::modname*', min_len=>1],
     req    => 1,
     pos    => 0,
     greedy => 1,
@@ -20,7 +20,7 @@ our $arg_module_multiple = {
 };
 
 our $arg_module_single = {
-    schema => 'str*',
+    schema => 'perl::modname*',
     req    => 1,
     pos    => 0,
     completion => sub {
@@ -156,7 +156,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.59 of App::PMUtils (from Perl distribution App-PMUtils), released on 2016-07-17.
+This document describes version 0.60 of App::PMUtils (from Perl distribution App-PMUtils), released on 2016-07-20.
 
 =head1 SYNOPSIS
 
@@ -235,7 +235,7 @@ Arguments ('*' denotes required arguments):
 
 Absolutify each path.
 
-=item * B<module>* => I<array[str]>
+=item * B<module>* => I<array[perl::modname]>
 
 =item * B<pm> => I<bool> (default: 1)
 
@@ -286,7 +286,7 @@ shell:
 
 and it won't change directory if the module doesn't exist.
 
-=item * B<module>* => I<array[str]>
+=item * B<module>* => I<array[perl::modname]>
 
 =item * B<pm> => I<bool> (default: 1)
 
